[![Documentation Status](https://readthedocs.org/projects/myp/badge/?version=latest)](myp.readthedocs.io/en/latest/?badge=latest)

# <img height="24" width="24" src="https://raw.githubusercontent.com/YunisDEV/myp/master/docs/myp_icon.svg"/> ManageYourPython

## What is MYP?
**myp** is a tool that helps you to manage and develop your Python apps easily.

## Learn more about MYP

Full documentation is available at [ReadTheDocs](https://myp.readthedocs.io).